﻿Namespace TTX
	''' <summary>
	''' CtpVb6的函数
	''' </summary>
	Public Interface ICtpVb6Function
		''' <summary>
		''' 用户登录请求
		''' </summary>
		''' <param name="brokerId">期货公司代码</param>
		''' <param name="marketDataServerAddressList">行情服务器地址列表</param>
		''' <param name="tradeServerAddressList">交易服务器地址列表</param>
		''' <param name="userId">账户代码</param>
		''' <param name="password">交易密码</param>
		''' <param name="authCode">认证码,可不填</param>
		''' <param name="userProductInfo">用户端产品信息,可不填</param>
		''' <returns>零为发送请求成功;非零为发送请求失败,查看错误代码表获取对应信息</returns>
		''' <remarks>
		''' 1、服务器地址列表,如果有多个则用逗号(,)隔开,每个地址的格式为：tcp://IP地址:端口 或者 tcp://域名:端口;
		''' 2、如果期货公司要求进行客户端认证,则要填写认证码和用户端产品信息。
		''' </remarks>
		Function Login(
		               ByVal brokerId As String, 
		               ByVal marketDataServerAddressList As String, 
		               ByVal tradeServerAddressList As String, 
		               ByVal userId As String, 
		               ByVal password As String, 
		               Optional ByVal authCode As String = "", 
		               Optional ByVal userProductInfo As String = ""
		               ) As Integer

		''' <summary>
		''' 用户登录请求(使用配置文件)
		''' </summary>
		''' <param name="configFile">配置文件(参考附带的:配置文件模板.xml,兼容快期的配置文件)</param>
		''' <param name="userId">账户代码</param>
		''' <param name="password">交易密码</param>
		''' <param name="serverName">要使用的服务器组名称,默认使用第一个</param>
		''' <returns>零为发送请求成功;非零为发送请求失败,查看错误代码表获取对应信息。</returns>
		''' <remarks>
		''' 1、如果期货公司要求进行客户端认证,则要填写认证码和用户端产品信息。
		''' </remarks>
		Function LoginByConfigFile(
		                           ByVal configFile As String, 
		                           ByVal userId As String, 
		                           ByVal password As String, 
		                           Optional ByVal serverName As String = ""
		                           ) As Integer

		''' <summary>
		''' 清理组件
		''' </summary>
		''' <remarks>
		''' 1、如果不使用组件了,应当调用本方法以清理组件占用的系统资源。
		''' 2、清理组件后如果想重新登录则需要重新创建一个组件实例。
		''' </remarks>
		Sub Release()

		''' <summary>
		''' 是否已登录交易服务器
		''' </summary>
		Function IsTradeServerLogined() As Boolean

		''' <summary>
		''' 是否已登录行情服务器
		''' </summary>
		Function IsMarketDataServerLogined() As Boolean

		''' <summary>
		''' 是否已完成初始化
		''' </summary>
		Function IsInitialized() As Boolean

		''' <summary>
		''' 是否已清理组件
		''' </summary>
		Function IsReleased() As Boolean

		''' <summary>
		''' 交易日
		''' </summary>
		Function GetTradingDay() As Date

		''' <summary>
		''' 获取交易所时间
		''' </summary>
		''' <param name="shfeTime">上期所时间</param>
		''' <param name="czceTime">郑商所时间</param>
		''' <param name="dceTime">大商所时间</param>
		''' <param name="cffexTime">中金所时间</param>
		''' <param name="ineTime">能交所时间</param>
		Function GetExchangeTime(
		                         ByRef shfeTime As Date, 
		                         ByRef czceTime As Date, 
		                         ByRef dceTime As Date,
		                         ByRef cffexTime As Date, 
		                         ByRef ineTime As Date
		                         ) As Boolean

		''' <summary>
		''' 获取帐户资金信息
		''' </summary>
		''' <returns>成功返回具体的值,失败返回null(VB中的Nothing)</returns>
		Function GetTradingAccount() As TradingAccountInfo

		'///////////////////////////////////////////////////////////////////////////////////////
		'///////////////////////////////////////////////////////////////////////////////////////

		''' <summary>
		''' 获取合约数量
		''' </summary>
		Function GetInstrumentCount() As Integer

		''' <summary>
		''' 获取合约信息
		''' </summary>
		''' <param name="index">索引</param>
		''' <returns>成功返回具体的值,失败返回null(VB中的Nothing)</returns>
		Function GetInstrumentByIndex(ByVal index As Integer) As InstrumentInfo

		''' <summary>
		''' 获取合约信息
		''' </summary>
		''' <param name="instrumentId">合约代码</param>
		''' <returns>成功返回具体的值,失败返回null(VB中的Nothing)</returns>
		Function GetInstrumentById(ByVal instrumentId As String) As InstrumentInfo

		''' <summary>
		''' 获取合约状态
		''' </summary>
		''' <param name="instrumentId">合约代码</param>
		''' <returns>
		''' -1=获取失败,
		''' 48=开盘前(BeforeTrading),
		''' 49=非交易(NoTrading),
		''' 50=连续交易(Continous),
		''' 51=集合竞价报单(AuctionOrdering),
		''' 52=集合竞价价格平衡(AuctionBalance),
		''' 53=集合竞价撮合(AuctionMatch),
		''' 54=收盘(Closed)</returns>
		Function GetInstrumentStatus(ByVal instrumentId As String) As Integer

		''' <summary>
		''' 获取行情
		''' </summary>
		''' <param name="instrumentId">合约代码</param>
		''' <returns>成功返回具体的值,失败返回null(VB中的Nothing)</returns>
		''' <remarks>如果查询失败且没有订阅行情则自动订阅</remarks>
		Function GetMarketData(ByVal instrumentId As String) As MarketDataInfo

		''' <summary>
		''' 是否已订阅行情
		''' </summary>
		''' <param name="instrumentId">合约代码</param>
		Function IsMarketDataSubscribed(ByVal instrumentId As String) As Boolean

		''' <summary>
		''' 订阅行情
		''' </summary>
		''' <param name="instrumentId">合约代码</param>
		''' <returns>零为发送请求成功;非零为发送请求失败,查看错误代码表获取对应信息。</returns>
		Function SubscribeMarketData(ByVal instrumentId As String) As Integer

		''' <summary>
		''' 批量订阅行情
		''' </summary>
		''' <param name="instrumentIdArray">合约代码的数组</param>
		''' <returns>零为发送请求成功;非零为发送请求失败,查看错误代码表获取对应信息。</returns>
		Function SubscribeMarketDataEx(ByVal instrumentIdArray() As String) As Integer

		''' <summary>
		''' 退订行情
		''' </summary>
		''' <param name="instrumentId">合约代码</param>
		''' <returns>零为发送请求成功;非零为发送请求失败,查看错误代码表获取对应信息。</returns>
		Function UnsubscribeMarketData(ByVal instrumentId As String) As Integer

		''' <summary>
		''' 批量退订行情
		''' </summary>
		''' <param name="instrumentIdArray">合约代码的数组</param>
		''' <returns>零为发送请求成功;非零为发送请求失败,查看错误代码表获取对应信息。</returns>
		Function UnsubscribeMarketDataEx(ByVal instrumentIdArray() As String) As Integer

		'///////////////////////////////////////////////////////////////////////////////////////
		'///////////////////////////////////////////////////////////////////////////////////////

		''' <summary>
		''' 报单
		''' </summary>
		''' <param name="instrumentId">合约代码</param>
		''' <param name="volume">数量</param>
		''' <param name="price">价格</param>
		''' <param name="direction">买卖方向,48=买(Buy);49=卖(Sell)</param>
		''' <param name="offsetFlag">开平标志1,48=开仓(Open),49=平仓(Close),50=强平(ForceClose),51=平今(CloseToday),52=平昨(CloseYesterday),53=强减(ForceOff),54=本地强平(LocalForceClose)</param>
		''' <param name="orderPriceType">报单价格条件类型:
		''' 49=任意价(AnyPrice),
		''' 50=限价(LimitPrice),
		''' 51=最优价(BestPrice),
		''' 52=最新价(LastPrice),
		''' 53=最新价浮动上浮1个ticks(LastPricePlusOneTicks),
		''' 54=最新价浮动上浮2个ticks(LastPricePlusTwoTicks),
		''' 55=最新价浮动上浮3个ticks(LastPricePlusThreeTicks),
		''' 56=卖一价(AskPrice1),
		''' 57=卖一价浮动上浮1个ticks(AskPrice1PlusOneTicks),
		''' 65=卖一价浮动上浮2个ticks(AskPrice1PlusTwoTicks),
		''' 66=卖一价浮动上浮3个ticks(AskPrice1PlusThreeTicks),
		''' 67=买一价(BidPrice1),
		''' 68=买一价浮动上浮1个ticks(BidPrice1PlusOneTicks),
		''' 69=买一价浮动上浮2个ticks(BidPrice1PlusTwoTicks),
		''' 70=买一价浮动上浮3个ticks(BidPrice1PlusThreeTicks),
		''' 71=五档价(FiveLevelPrice)</param>
		''' <param name="contingentCondition">触发条件:
		''' 49=立即(Immediately),
		''' 50=止损(Touch),
		''' 51=止赢(TouchProfit),
		''' 52=预埋单(ParkedOrder),
		''' 53=最新价大于条件价(LastPriceGreaterThanStopPrice),
		''' 54=最新价大于等于条件价(LastPriceGreaterEqualStopPrice),
		''' 55=最新价小于条件价(LastPriceLesserThanStopPrice),
		''' 56=最新价小于等于条件价(LastPriceLesserEqualStopPrice),
		''' 57=卖一价大于条件价(AskPriceGreaterThanStopPrice),
		''' 65=卖一价大于等于条件价(AskPriceGreaterEqualStopPrice),
		''' 66=卖一价小于条件价(AskPriceLesserThanStopPrice),
		''' 67=卖一价小于等于条件价(AskPriceLesserEqualStopPrice),
		''' 68=买一价大于条件价(BidPriceGreaterThanStopPrice),
		''' 69=买一价大于等于条件价(BidPriceGreaterEqualStopPrice),
		''' 70=买一价小于条件价(BidPriceLesserThanStopPrice),
		''' 72=买一价小于等于条件价(BidPriceLesserEqualStopPrice)</param>
		''' <param name="stopPrice">止损价(条件价)</param>
		''' <param name="volumeCondition">成交量类型:49=任何数量(AV),50=最小数量(MV),51=全部数量(CV)</param>
		''' <param name="minVolume">最小成交量</param>
		''' <param name="timeCondition">有效期类型:49=立即完成,否则撤销(IOC),50=本节有效(GFS),51=当日有效(GFD),52=指定日期前有效(GTD),53=撤销前有效(GTC),54=集合竞价有效(GFA)</param>
		''' <returns>
		''' 1.大于等于零表示报单发送成功,返回的是报单序号;
		''' 2.小于零表示报单发送失败,返回的是响应代码,请检查代码含义.
		''' </returns>
		''' <remarks>SimNow模拟交易中,大连,郑州,中金,不支持市价,但实盘支持</remarks>
		Function InsertOrder(
		                     ByVal instrumentId As String, 
		                     ByVal volume As Integer, 
		                     ByVal price As Double, 
		                     ByVal direction As Integer, 
		                     ByVal offsetFlag As Integer, 
		                     Optional ByVal orderPriceType As Integer = 50, 
		                     Optional ByVal contingentCondition As Integer = 49, 
		                     Optional ByVal stopPrice As Double = 0.0, 
		                     Optional ByVal volumeCondition As Integer = 49, 
		                     Optional ByVal minVolume As Integer = 1, 
		                     Optional ByVal timeCondition As Integer = 51
		                     ) As Integer

		''' <summary>
		''' 多头开仓
		''' </summary>
		''' <param name="instrumentId">合约代码</param>
		''' <param name="volume">数量</param>
		''' <param name="price">价格,零为市价</param>
		''' <returns>
		''' 1.大于等于零表示报单发送成功,返回的是报单序号;
		''' 2.小于零表示报单发送失败,返回的是响应代码,请检查代码含义.
		''' </returns>
		''' <remarks>
		''' 1.SimNow模拟交易中,大连,郑州,中金,不支持市价,但实盘支持;
		''' 2.上期所合约的市价单转换为停板价的限价单然后立即撤单.
		''' </remarks>
		Function OpenLong(ByVal instrumentId As String, ByVal volume As Integer, ByVal price As Double) As Integer

		''' <summary>
		''' 空头开仓
		''' </summary>
		''' <param name="instrumentId">合约代码</param>
		''' <param name="volume">数量</param>
		''' <param name="price">价格,零为市价</param>
		''' <returns>
		''' 1.大于等于零表示报单发送成功,返回的是报单序号;
		''' 2.小于零表示报单发送失败,返回的是响应代码,请检查代码含义.
		''' </returns>
		''' <remarks>
		''' 1.SimNow模拟交易中,大连,郑州,中金,不支持市价,但实盘支持;
		''' 2.上期所合约的市价单转换为停板价的限价单然后立即撤单.
		''' </remarks>
		Function OpenShort(ByVal instrumentId As String, ByVal volume As Integer, ByVal price As Double) As Integer

		''' <summary>
		''' 多头平仓
		''' </summary>
		''' <param name="instrumentId">合约代码</param>
		''' <param name="volume">数量</param>
		''' <param name="price">价格,零为市价</param>
		''' <returns>
		''' 1.大于等于零表示报单发送成功,返回的是报单序号;
		''' 2.等于零表示上期所合约平仓数量中包含今仓和昨仓,指令被分拆为平今和平昨两条指令发送;
		''' 3.小于零表示报单发送失败,返回的是响应代码,请检查代码含义.
		''' </returns>
		''' <remarks>
		''' 1.SimNow模拟交易中,大连,郑州,中金,不支持市价,但实盘支持;
		''' 2.上期所合约的市价单转换为停板价的限价单然后立即撤单;
		''' 3.上期所合约不区分平今平昨,优先平今,如果想先平昨,请使用InsertOrder指令
		''' </remarks>
		Function CloseLong(ByVal instrumentId As String, ByVal volume As Integer, ByVal price As Double) As Integer

		''' <summary>
		''' 空头平仓
		''' </summary>
		''' <param name="instrumentId">合约代码</param>
		''' <param name="volume">数量</param>
		''' <param name="price">价格,零为市价</param>
		''' <returns>
		''' 1.大于等于零表示报单发送成功,返回的是报单序号;
		''' 2.等于零表示上期所合约平仓数量中包含今仓和昨仓,指令被分拆为平今和平昨两条指令发送;
		''' 3.小于零表示报单发送失败,返回的是响应代码,请检查代码含义.
		''' </returns>
		''' <remarks>
		''' 1.SimNow模拟交易中,大连,郑州,中金,不支持市价,但实盘支持;
		''' 2.上期所合约的市价单转换为停板价的限价单然后立即撤单;
		''' 3.上期所合约不区分平今平昨,优先平今,如果想先平昨,请使用InsertOrder指令
		''' </remarks>
		Function CloseShort(ByVal instrumentId As String, ByVal volume As Integer, ByVal price As Double) As Integer

		''' <summary>
		''' 撤单
		''' </summary>
		''' <param name="orderSn">报单序号</param>
		''' <returns>零为发送请求成功;非零为发送请求失败,查看错误代码表获取对应信息。</returns>
		Function CancelOrder(ByVal orderSn As Integer) As Integer

		''' <summary>
		''' 批量撤单
		''' </summary>
		''' <param name="instrumentId">合约代码,空字符串为不指定</param>
		''' <param name="direction">买卖方向,零为不指定,48=买(Buy);49=卖(Sell)</param>
		''' <param name="offsetFlag">开平标志,零为不指定,上期所合约使用Close平仓标志时不区分今仓和昨仓,48=开仓(Open),49=平仓(Close),50=强平(ForceClose),51=平今(CloseToday),52=平昨(CloseYesterday),53=强减(ForceOff),54=本地强平(LocalForceClose)</param>
		Sub CancelOrderEx(Optional ByVal instrumentId As String = "", 
		                  Optional ByVal direction As Integer = 0, 
		                  Optional ByVal offsetFlag As Integer = 0)

		''' <summary>
		''' 获取报单状态
		''' </summary>
		''' <param name="orderSn">报单序号</param>
		''' <returns>
		''' -1=获取失败;
		''' 48=全部成交(AllTraded);
		''' 49=部分成交还在队列中(PartTradedQueueing);
		''' 50=部分成交不在队列中(PartTradedNotQueueing);
		''' 51=未成交还在队列中(NoTradeQueueing);
		''' 52=未成交不在队列中(NoTradeNotQueueing);
		''' 53=撤单(Canceled);
		''' 97=未知(Unknown);
		''' 98=尚未触发(NotTouched);
		''' 99=已触发(Touched)
		''' </returns>
		Function GetOrderStatus(ByVal orderSn As Integer) As Integer

		''' <summary>
		''' 报单是否处于可撤状态
		''' </summary>
		''' <param name="orderSn">报单序号</param>
		Function IsOrderOpen(ByVal orderSn As Integer) As Boolean

		''' <summary>
		''' 获取指定条件的报单序号列表
		''' </summary>
		''' <param name="instrumentId">合约代码,空字符串为不指定</param>
		''' <param name="direction">买卖方向,零为不指定,48=买(Buy);49=卖(Sell)</param>
		''' <param name="offsetFlag">开平标志,零为不指定,上期所合约使用Close平仓标志时不区分今仓和昨仓,48=开仓(Open),49=平仓(Close),50=强平(ForceClose),51=平今(CloseToday),52=平昨(CloseYesterday),53=强减(ForceOff),54=本地强平(LocalForceClose)</param>
		''' <param name="orderStatus">报单状态:
		''' 0=不指定,
		''' 1=还在挂单,
		''' 48=全部成交(AllTraded);
		''' 49=部分成交还在队列中(PartTradedQueueing);
		''' 50=部分成交不在队列中(PartTradedNotQueueing);
		''' 51=未成交还在队列中(NoTradeQueueing);
		''' 52=未成交不在队列中(NoTradeNotQueueing);
		''' 53=撤单(Canceled);
		''' 97=未知(Unknown);
		''' 98=尚未触发(NotTouched);
		''' 99=已触发(Touched)</param>
		Function GetOrderSnList(Optional ByVal instrumentId As String = "", 
		                        Optional ByVal direction As Integer = 0,
		                        Optional ByVal offsetFlag As Integer = 0, 
		                        Optional ByVal orderStatus As Integer = 0
		                        ) As Integer()

		''' <summary>
		''' 获取报单信息
		''' </summary>
		''' <param name="orderSn">报单序号</param>
		''' <returns>成功返回具体的值,失败返回null(VB中的Nothing)</returns>
		Function GetOrderBySn(ByVal orderSn As Integer) As OrderInfo

		''' <summary>
		''' 获取指定合约的持仓信息
		''' </summary>
		''' <param name="instrumentId">合约代码</param>
		''' <param name="direction">买卖方向,48=买(Buy);49=卖(Sell)</param>
		''' <returns>成功返回具体的值,失败返回null(VB中的Nothing)</returns>
		Function GetPosition(ByVal instrumentId As String, ByVal direction As Integer) As PositionInfo

		'///////////////////////////////////////////////////////////////////////////////////////
		'///////////////////////////////////////////////////////////////////////////////////////

		''' <summary>
		''' 获取银行开销户信息数量
		''' </summary>
		Function GetBankAccountRegisterCount() As Integer

		''' <summary>
		''' 获取银行开销户信息
		''' </summary>
		''' <param name="index">索引</param>
		''' <returns>成功返回具体的值,失败返回null(VB中的Nothing)</returns>
		Function GetBankAccountRegisterByIndex(ByVal index As Integer) As BankAccountRegisterInfo

		''' <summary>
		''' 查询银行余额
		''' </summary>
		''' <param name="bankId">银行编码</param>
		''' <param name="bankBranchId">银行分支机构代码</param>
		''' <param name="bankAccount">银行帐号</param>
		''' <param name="bankPassword">银行密码</param>
		''' <param name="tradingAccountPassword">期货资金密码</param>
		''' <param name="currencyId">币种代码,默认为:CNY(人民币)</param>
		''' <returns>零为发送请求成功;非零为发送请求失败,查看错误代码表获取对应信息。</returns>
		''' <remarks>在响应事件中接收结果</remarks>
		Function QueryBankAccountMoney(ByVal bankId As String, 
		                               ByVal bankBranchId As String,
		                               ByVal bankAccount As String, 
		                               ByVal bankPassword As String, 
		                               ByVal tradingAccountPassword As String,
		                               Optional ByVal currencyId As String = "CNY"
		                               ) As Integer

		''' <summary>
		''' 银行资金转期货
		''' </summary>
		''' <param name="bankId">银行编码</param>
		''' <param name="bankBranchId">银行分支机构代码</param>
		''' <param name="bankAccount">银行帐号</param>
		''' <param name="bankPassword">银行密码</param>
		''' <param name="tradingAccountPassword">期货资金密码</param>
		''' <param name="amount">转帐金额</param>
		''' <param name="currencyId">币种代码,默认为:人民币CNY</param>
		''' <returns>零为发送请求成功;非零为发送请求失败,查看错误代码表获取对应信息。</returns>
		Function FromBankToFuture(ByVal bankId As String,
		                          ByVal bankBranchId As String, 
		                          ByVal bankAccount As String, 
		                          ByVal bankPassword As String, 
		                          ByVal tradingAccountPassword As String, 
		                          ByVal amount As Double, 
		                          Optional ByVal currencyId As String = "CNY"
		                          ) As Integer

		''' <summary>
		''' 期货资金转银行
		''' </summary>
		''' <param name="bankId">银行编码</param>
		''' <param name="bankBranchId">银行分支机构代码</param>
		''' <param name="bankAccount">银行帐号</param>
		''' <param name="bankPassword">银行密码</param>
		''' <param name="tradingAccountPassword">期货资金密码</param>
		''' <param name="amount">转帐金额</param>
		''' <param name="currencyId">币种代码,默认为:人民币CNY</param>
		''' <returns>零为发送请求成功;非零为发送请求失败,查看错误代码表获取对应信息。</returns>
		Function FromFutureToBank(ByVal bankId As String, 
		                          ByVal bankBranchId As String, 
		                          ByVal bankAccount As String, 
		                          ByVal bankPassword As String, 
		                          ByVal tradingAccountPassword As String,
		                          ByVal amount As Double, 
		                          Optional ByVal currencyId As String = "CNY"
		                          ) As Integer

		''' <summary>
		''' 查询合约保证金率
		''' </summary>
		''' <param name="instrumentId">合约代码</param>
		''' <returns>成功返回具体的值,失败返回null(VB中的Nothing)</returns>
		''' <remarks>
		''' 1.内部会缓存当前交易日成功查询的结果,跨越交易日重新登录后将清空缓存;
		''' 2.获取失败则自动向期货公司查询,可以在查询响应事件中接收结果,或者稍后再重复查询.
		''' </remarks>
		Function QueryMarginRate(ByVal instrumentId As String) As InstrumentMarginRateInfo

		''' <summary>
		''' 查询合约手续费率
		''' </summary>
		''' <param name="instrumentId">合约代码</param>
		''' <returns>成功返回具体的值,失败返回null(VB中的Nothing)</returns>
		''' <remarks>
		''' 1.内部会缓存当前交易日成功查询的结果,跨越交易日重新登录后将清空缓存;
		''' 2.获取失败则自动向期货公司查询,可以在查询响应事件中接收结果,或者稍后再重复查询.
		''' </remarks>
		Function QueryCommissionRate(ByVal instrumentId As String) As InstrumentCommissionRateInfo

		''' <summary>
		''' 查询合约报单手续费率
		''' </summary>
		''' <param name="instrumentId">合约代码</param>
		''' <returns>成功返回具体的值,失败返回null(VB中的Nothing)</returns>
		''' <remarks>
		''' 1.内部会缓存当前交易日成功查询的结果,跨越交易日重新登录后将清空缓存;
		''' 2.获取失败则自动向期货公司查询,可以在查询响应事件中接收结果,或者稍后再重复查询.
		''' </remarks>
		Function QueryOrderCommissionRate(ByVal instrumentId As String) As InstrumentOrderCommissionRateInfo

		''' <summary>
		''' 更新交易密码
		''' </summary>
		''' <param name="oldPassword">旧密码</param>
		''' <param name="newPassword">新密码</param>
		''' <returns>零为发送请求成功;非零为发送请求失败,查看错误代码表获取对应信息。</returns>
		Function UpdateUserPassword(ByVal oldPassword As String, ByVal newPassword As String) As Integer

		''' <summary>
		''' 更新资金密码
		''' </summary>
		''' <param name="oldPassword">旧密码</param>
		''' <param name="newPassword">新密码</param>
		''' <param name="currencyId">币种代码,默认为:CNY(人民币)</param>
		''' <returns>零为发送请求成功;非零为发送请求失败,查看错误代码表获取对应信息。</returns>
		Function UpdateTradingAccountPassword(ByVal oldPassword As String, 
		                                      ByVal newPassword As String, 
		                                      Optional ByVal currencyId As String = "CNY"
		                                      ) As Integer

		''' <summary>
		''' 获取朗读引擎名称
		''' </summary>
		Function GetSpeakerNames() As String()

		''' <summary>
		''' 设置朗读参数
		''' </summary>
		''' <param name="speakerName">朗读引擎名称,空字符串表示第一个朗读引擎</param>
		''' <param name="volume">朗读音量 [范围 0 ~ 1]</param>
		''' <param name="rate">朗读频率 [范围 -10 ~ 10]</param>
		Function SetSpeakParameter(Optional ByVal speakerName As String = "", 
		                           Optional ByVal volume As Integer = 1, 
		                           Optional ByVal rate As Integer = 0
		                           ) As Boolean

		''' <summary>
		''' 语音朗读
		''' </summary>
		''' <param name="text">要朗读的文本</param>
		''' <param name="cancelBefore">是否取消之前没有读完的语音,默认是,如果不取消且之前还在朗读则多段语音串行朗读</param>
		Sub Speak(ByVal text As String, Optional ByVal cancelBefore As Boolean = True)

		'///////////////////////////////////////////////////////////////////////////////////////
		'///////////////////////////////////////////////////////////////////////////////////////

		''' <summary>
		''' 查询期权交易成本
		''' </summary>
		''' <param name="instrumentId">合约代码</param>
		''' <returns>成功返回具体的值,失败返回null(VB中的Nothing)</returns>
		''' <remarks>
		''' 1.内部会缓存当前交易日成功查询的结果,跨越交易日重新登录后将清空缓存;
		''' 2.获取失败则自动向期货公司查询,可以在查询响应事件中接收结果,或者稍后再重复查询.
		''' </remarks>
		Function QueryOptionTradeCost(ByVal instrumentId As String) As OptionInstrumentTradeCostInfo

		''' <summary>
		''' 查询期权合约手续费率
		''' </summary>
		''' <param name="instrumentId">合约代码</param>
		''' <returns>成功返回具体的值,失败返回null(VB中的Nothing)</returns>
		''' <remarks>
		''' 1.内部会缓存当前交易日成功查询的结果,跨越交易日重新登录后将清空缓存;
		''' 2.获取失败则自动向期货公司查询,可以在查询响应事件中接收结果,或者稍后再重复查询.
		''' </remarks>
		Function QueryOptionCommissionRate(ByVal instrumentId As String) As OptionInstrumentCommissionRateInfo

		''' <summary>
		''' 询价
		''' </summary>
		''' <param name="instrumentId">合约代码</param>
		''' <returns>零为发送请求成功;非零为发送请求失败,查看错误代码表获取对应信息。</returns>
		Function InsertForQuote(ByVal instrumentId As String) As Integer

		''' <summary>
		''' 执行宣告
		''' </summary>
		''' <param name="instrumentId">合约代码</param>
		''' <param name="volume">数量</param>
		''' <param name="actionType">执行类型,49=执行(Exec),50=放弃(Abandon)</param>
		''' <param name="closeFlag">期权行权后生成的头寸是否自动平仓,48=自动平仓(AutoClose),49=免于自动平仓(NotToClose)</param>
		''' <param name="reservePositionFlag">期权行权后是否保留期货头寸的标记,48=保留(Reserve),49=不保留(UnReserve)</param>
		''' <param name="posiDirection">保留头寸申请的持仓方向,49=净(Net),50=多头(Long),51=空头(Short)</param>
		''' <param name="offsetFlag">开平标志,49=平仓(Close),51=平今(CloseToday)</param>
		''' <returns>
		''' 1、正整数为发送成功,返回唯一标识一个执行宣告的执行宣告序号OrderSN;
		''' 2、其它为发送请求失败,查看错误代码表获取对应信息。
		''' </returns>
		Function InsertExecOrder(ByVal instrumentId As String, 
		                         ByVal volume As Integer, 
		                         ByVal actionType As Integer, 
		                         ByVal closeFlag As Integer, 
		                         ByVal reservePositionFlag As Integer, 
		                         ByVal posiDirection As Integer, 
		                         ByVal offsetFlag As Integer
		                         ) As Integer

		''' <summary>
		''' 获取执行宣告状态
		''' </summary>
		''' <param name="orderSn">执行宣告序号</param>
		''' <returns>
		''' -1=获取失败;
		''' 110=没有执行(NoExec);
		''' 99=已经取消(Canceled);
		''' 48=执行成功(OK);
		''' 49=期权持仓不够(NoPosition);
		''' 50=资金不够(NoDeposit);
		''' 51=会员不存在(NoParticipant);
		''' 52=客户不存在(NoClient);
		''' 53=合约不存在(NoInstrument);
		''' 54=没有执行权限(NoRight);
		''' 55=不合理的数量(InvalidVolume);
		''' 56=没有足够的历史成交(NoEnoughHistoryTrade);
		''' 97=未知(Unknown)</returns>
		Function GetExecOrderStatus(ByVal orderSn As Integer) As Integer

		''' <summary>
		''' 执行宣告是否还没有执行
		''' </summary>
		''' <param name="orderSn">执行宣告序号</param>
		Function IsOrderExecuting(ByVal orderSn As Integer) As Boolean

		''' <summary>
		''' 撤销执行宣告
		''' </summary>
		''' <param name="orderSn">执行宣告序号</param>
		''' <returns>零为发送请求成功;非零为发送请求失败,查看错误代码表获取对应信息。</returns>
		Function CancelExecOrder(ByVal orderSn As Integer) As Integer

		''' <summary>
		''' 获取指定条件的没有执行的执行宣告的序号
		''' </summary>
		''' <param name="instrumentId">合约代码,空字符串则不指定</param>
		''' <param name="actionType">执行类型,0=不指定,49=执行(Exec),50=放弃(Abandon)</param>
		''' <param name="offsetFlag">开平标志:0=不指定,48=开仓(Open),49=平仓(Close),51=平今(CloseToday),52=平昨(CloseYesterday)</param>
		''' <param name="execResult">执行结果,零为不指定,
		''' 110=没有执行(NoExec);
		''' 99=已经取消(Canceled);
		''' 48=执行成功(OK);
		''' 49=期权持仓不够(NoPosition);
		''' 50=资金不够(NoDeposit);
		''' 51=会员不存在(NoParticipant);
		''' 52=客户不存在(NoClient);
		''' 53=合约不存在(NoInstrument);
		''' 54=没有执行权限(NoRight);
		''' 55=不合理的数量(InvalidVolume);
		''' 56=没有足够的历史成交(NoEnoughHistoryTrade);
		''' 97=未知(Unknown)</param>
		Function GetExecOrderSnList(Optional ByVal instrumentId As String = "", 
		                            Optional ByVal actionType As Integer = 0,
		                            Optional ByVal offsetFlag As Integer = 0, 
		                            Optional ByVal execResult As Integer = 0
		                            ) As Integer()

		''' <summary>
		''' 获取执行宣告信息
		''' </summary>
		''' <param name="orderSn">执行宣告序号</param>
		Function GetExecOrderBySn(ByVal orderSn As Integer) As ExecOrderInfo

	End Interface

	''' <summary>
	''' CtpVb6的事件
	''' </summary>
	Public Interface ICtpVb6EventInterface
		''' <summary>
		''' 与行情服务器建立连接
		''' </summary>
		Sub OnMarketDataServerConnected()

		''' <summary>
		''' 与行情服务器断开连接
		''' </summary>
		Sub OnMarketDataServerDisconnected(ByVal rsp As RspInfo)

		''' <summary>
		''' 与交易服务器建立连接
		''' </summary>
		Sub OnTradeServerConnected()

		''' <summary>
		''' 与交易服务器断开连接
		''' </summary>
		Sub OnTradeServerDisconnected(ByVal rsp As RspInfo)

		''' <summary>
		''' 初始化响应
		''' </summary>
		Sub OnInitialized()

		''' <summary>
		''' 组件清理响应
		''' </summary>
		Sub OnReleased(ByVal rsp As RspInfo)

		''' <summary>
		''' 程序日志
		''' </summary>
		Sub OnLog(ByVal log As LogInfo)

		''' <summary>
		''' 资金信息变化
		''' </summary>
		Sub OnTradingAccount(ByVal info As TradingAccountInfo)

		''' <summary>
		''' 合约状态通知
		''' </summary>
		Sub OnInstrumentStatus(ByVal status As InstrumentStatusInfo)

		''' <summary>
		''' 行情通知
		''' </summary>
		Sub OnMarketData(ByVal marketData As MarketDataInfo)

		''' <summary>
		''' 报单通知
		''' </summary>
		<DispId(65)>
		Sub OnOrder(ByVal order As OrderInfo)

		''' <summary>
		''' 成交通知
		''' </summary>
		Sub OnTrade(ByVal trade As TradeInfo)

		''' <summary>
		''' 持仓变化
		''' </summary>
		Sub OnPosition(ByVal position As PositionInfo)

		''' <summary>
		''' 询价响应(询价失败)
		''' </summary>
		Sub OnInsertForQuote(ByVal info As InputForQuoteInfo, ByVal rsp As RspInfo)

		''' <summary>
		''' 执行宣告通知
		''' </summary>
		Sub OnExecOrdere(ByVal execOrder As ExecOrderInfo)

		''' <summary>
		''' 查询合约保证金率响应
		''' </summary>
		Sub OnQueryMarginRate(ByVal rate As InstrumentMarginRateInfo)

		''' <summary>
		''' 查询合约手续费率响应
		''' </summary>
		Sub OnQueryCommissionRate(ByVal rate As InstrumentCommissionRateInfo)

		''' <summary>
		''' 查询合约报单手续费率响应
		''' </summary>
		Sub OnQueryOrderCommissionRate(ByVal rate As InstrumentOrderCommissionRateInfo)

		''' <summary>
		''' 查询期权合约手续费率响应
		''' </summary>
		Sub OnQueryOptionCommissionRate(ByVal rate As OptionInstrumentCommissionRateInfo)

		''' <summary>
		''' 查询期权交易成本响应
		''' </summary>
		Sub OnQueryOptionTradeCost(ByVal cost As OptionInstrumentTradeCostInfo)

		''' <summary>
		''' 更新交易密码响应
		''' </summary>
		Sub OnUpdateUserPassword(ByVal info As UserPasswordUpdateInfo, ByVal rsp As RspInfo)

		''' <summary>
		''' 更新资金密码响应
		''' </summary>
		Sub OnUpdateTradingAccountPassword(ByVal info As TradingAccountPasswordUpdateInfo, ByVal rsp As RspInfo)

		''' <summary>
		''' 查询银行余额响应
		''' </summary>
		Sub OnQueryBankAccountMoney(ByVal info As QueryBankAccountMoneyInfo, ByVal rsp As RspInfo)

		''' <summary>
		''' 银行资金转期货响应
		''' </summary>
		Sub OnFromBankToFuture(ByVal info As TransferInfo, ByVal rsp As RspInfo)

		''' <summary>
		''' 期货资金转银行响应
		''' </summary>
		Sub OnFromFutureToBank(ByVal info As TransferInfo, ByVal rsp As RspInfo)
        
	End Interface
End Namespace
